# 📦 PyPI发布配置指南

## 🎯 概述

本指南将帮助你将高熵率软件熵源项目发布到PyPI（Python Package Index），让全世界的开发者都能通过 `pip install` 安装你的包。

## 📋 发布前准备

### 1. 注册PyPI账号

#### 正式PyPI
1. 访问 https://pypi.org/account/register/
2. 填写用户名、邮箱、密码
3. 验证邮箱地址

#### 测试PyPI（推荐先用这个测试）
1. 访问 https://test.pypi.org/account/register/
2. 同样填写注册信息
3. 验证邮箱地址

### 2. 生成API Token

#### 为什么需要API Token？
- 比用户名密码更安全
- 可以限制权限范围
- 可以随时撤销

#### 生成步骤：

**测试PyPI:**
1. 登录 https://test.pypi.org/
2. 点击右上角用户名 → Account settings
3. 滚动到 "API tokens" 部分
4. 点击 "Add API token"
5. Token name: `high-entropy-source-test`
6. Scope: 选择 "Entire account" 或特定项目
7. 点击 "Add token"
8. **重要**: 复制生成的token（以 `pypi-` 开头）

**正式PyPI:**
1. 登录 https://pypi.org/
2. 重复上述步骤
3. Token name: `high-entropy-source`

### 3. 配置本地认证

#### 方法1: 使用 .pypirc 文件（推荐）

在用户主目录创建 `.pypirc` 文件：

**Windows:** `C:\Users\你的用户名\.pypirc`
**Linux/Mac:** `~/.pypirc`

```ini
[distutils]
index-servers =
    pypi
    testpypi

[pypi]
username = __token__
password = pypi-你的正式PyPI_token

[testpypi]
repository = https://test.pypi.org/legacy/
username = __token__
password = pypi-你的测试PyPI_token
```

#### 方法2: 环境变量

```bash
# Windows PowerShell
$env:TWINE_USERNAME = "__token__"
$env:TWINE_PASSWORD = "pypi-你的token"

# Linux/Mac Bash
export TWINE_USERNAME="__token__"
export TWINE_PASSWORD="pypi-你的token"
```

## 🚀 发布流程

### 自动化发布（推荐）

```bash
python publish_to_pypi.py
```

这个脚本会自动：
1. ✅ 检查前提条件
2. 🗑️ 清理旧的构建文件
3. 📦 构建源码包和wheel包
4. 🔍 检查包质量
5. 🧪 上传到测试PyPI
6. 🚀 上传到正式PyPI

### 手动发布步骤

#### 1. 安装发布工具
```bash
pip install --upgrade pip setuptools wheel twine
```

#### 2. 清理旧文件
```bash
rm -rf build/ dist/ *.egg-info/
```

#### 3. 构建包
```bash
python setup.py sdist bdist_wheel
```

#### 4. 检查包质量
```bash
twine check dist/*
```

#### 5. 上传到测试PyPI
```bash
twine upload --repository testpypi dist/*
```

#### 6. 测试安装
```bash
pip install --index-url https://test.pypi.org/simple/ high-entropy-source
```

#### 7. 上传到正式PyPI
```bash
twine upload dist/*
```

## 🔧 包名称注意事项

### 检查名称可用性
```bash
# 检查PyPI
pip search high-entropy-source

# 或访问网页
# https://pypi.org/project/high-entropy-source/
```

### 如果名称被占用
修改 `setup.py` 和 `pyproject.toml` 中的包名：
```python
name="high-entropy-source-v2"  # 或其他唯一名称
```

## 📊 发布后管理

### 查看包信息
- 📦 包页面: https://pypi.org/project/high-entropy-source/
- 📈 下载统计: https://pypistats.org/packages/high-entropy-source
- 🔍 包搜索: https://pypi.org/search/?q=high-entropy-source

### 更新版本
1. 修改 `setup.py` 中的版本号
2. 修改 `pyproject.toml` 中的版本号
3. 重新运行发布流程

### 删除版本（谨慎操作）
- 登录PyPI网站
- 进入项目管理页面
- 选择要删除的版本

## 🛡️ 安全最佳实践

### 1. API Token安全
- ❌ 不要将token提交到Git
- ✅ 使用环境变量或.pypirc文件
- ✅ 定期轮换token
- ✅ 为不同项目使用不同token

### 2. 版本管理
- ✅ 使用语义化版本号 (1.0.0, 1.0.1, 1.1.0)
- ✅ 在发布前充分测试
- ✅ 写清楚CHANGELOG

### 3. 包内容检查
- ✅ 确保不包含敏感信息
- ✅ 检查文件权限
- ✅ 验证依赖包版本

## 🎯 用户安装体验

发布成功后，用户可以：

```bash
# 安装你的包
pip install high-entropy-source

# 使用你的包
python -c "from src.entropy_source import OptimizedEntropySource; print('安装成功!')"

# 运行演示
entropy-demo  # 如果配置了console_scripts

# 升级包
pip install --upgrade high-entropy-source
```

## 🔍 故障排除

### 常见错误

#### 1. "Package already exists"
- 原因：包名已被使用或版本号重复
- 解决：更改包名或增加版本号

#### 2. "Invalid authentication"
- 原因：API token错误或过期
- 解决：重新生成token并更新配置

#### 3. "File already exists"
- 原因：相同版本已上传
- 解决：增加版本号

#### 4. "Package description invalid"
- 原因：README.md格式问题
- 解决：检查Markdown语法

### 调试技巧

```bash
# 详细输出
twine upload --verbose dist/*

# 检查包内容
tar -tzf dist/high-entropy-source-1.0.0.tar.gz

# 测试本地安装
pip install dist/high-entropy-source-1.0.0.tar.gz
```

## 🎉 发布成功后

### 1. 更新项目文档
在README.md中添加安装说明：
```markdown
## 安装

```bash
pip install high-entropy-source
```

### 2. 宣传推广
- 📱 在社交媒体分享
- 📝 写技术博客
- 🎯 参加技术会议
- 📧 通知相关社区

### 3. 维护更新
- 🐛 及时修复bug
- 📈 监控下载量和反馈
- 🔄 定期更新依赖
- 📚 完善文档

---

🎊 **恭喜！你的项目现在可以被全世界的Python开发者使用了！**
