#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
高熵率高吞吐软件熵源 - 安装脚本
"""

from setuptools import setup, find_packages
import os

# 读取README文件
def read_readme():
    with open("README.md", "r", encoding="utf-8") as f:
        return f.read()

# 读取requirements文件
def read_requirements():
    with open("requirements.txt", "r", encoding="utf-8") as f:
        return [line.strip() for line in f if line.strip() and not line.startswith("#")]

setup(
    name="high-entropy-source",  # 注意：这个名字必须在PyPI上唯一
    version="1.0.2",
    author="Your Name",  # 替换为你的真实姓名
    author_email="your.email@example.com",  # 替换为你的邮箱
    description="High-performance software entropy source with 175x throughput improvement",
    long_description=read_readme(),
    long_description_content_type="text/markdown",
    url="https://github.com/yourusername/high-entropy-source",  # 替换为你的GitHub仓库
    packages=["high_entropy_source_v2"],
    package_dir={"high_entropy_source": "high_entropy_source_v2"},
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "Intended Audience :: Science/Research",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Topic :: Security :: Cryptography",
        "Topic :: Scientific/Engineering",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ],
    python_requires=">=3.7",
    install_requires=read_requirements(),
    extras_require={
        "dev": [
            "pytest>=6.0.0",
            "pytest-cov>=2.12.0",
            "black>=21.0.0",
            "flake8>=3.9.0",
        ],
        "docs": [
            "sphinx>=4.0.0",
            "sphinx-rtd-theme>=0.5.0",
        ],
    },
    entry_points={
        "console_scripts": [
            "entropy-demo=demo.web_demo:main",
            "entropy-test=tests.performance_test:main",
        ],
    },
    include_package_data=True,
    package_data={
        "demo": ["templates/*.html"],
    },
    keywords="entropy, random, cryptography, security, NIST, performance",
    project_urls={
        "Bug Reports": "https://github.com/yourusername/high-entropy-source/issues",
        "Source": "https://github.com/yourusername/high-entropy-source",
        "Documentation": "https://high-entropy-source.readthedocs.io/",
    },
)
