#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
测试新的随机数据格式生成功能
"""

import requests
import json
import time

def test_format_generation():
    """测试不同格式的随机数据生成"""
    base_url = "http://localhost:5000"
    
    # 首先启动熵源
    print("🚀 启动熵源系统...")
    start_response = requests.post(f"{base_url}/api/start")
    if start_response.json().get('success'):
        print("✅ 熵源启动成功")
        time.sleep(3)  # 等待预热
    else:
        print("❌ 熵源启动失败")
        return
    
    # 测试不同的格式
    test_cases = [
        {'format': 'password', 'size': 16, 'description': '16位强密码'},
        {'format': 'letters', 'size': 20, 'description': '20个随机字母'},
        {'format': 'numbers', 'size': 10, 'description': '10个随机数字'},
        {'format': 'alphanumeric', 'size': 15, 'description': '15个字母数字混合'},
        {'format': 'symbols', 'size': 12, 'description': '12个包含符号的字符'},
        {'format': 'uuid', 'size': 5, 'description': '5个UUID'},
        {'format': 'base64', 'size': 64, 'description': '64字节Base64编码'},
        {'format': 'hex', 'size': 32, 'description': '32字节十六进制'}
    ]
    
    print("\n📊 测试不同格式的随机数据生成:")
    print("=" * 60)
    
    for test_case in test_cases:
        print(f"\n🔸 测试: {test_case['description']}")
        
        # 发送生成请求
        generate_data = {
            'size': test_case['size'],
            'format': test_case['format']
        }
        
        try:
            response = requests.post(
                f"{base_url}/api/generate",
                headers={'Content-Type': 'application/json'},
                json=generate_data
            )
            
            result = response.json()
            
            if result.get('success'):
                print(f"✅ 生成成功")
                print(f"   大小: {result.get('size', 0)} 字节")
                print(f"   耗时: {result.get('generation_time', 0):.4f} 秒")
                print(f"   吞吐量: {result.get('throughput_mb', 0):.2f} MB/s")
                
                # 显示生成的数据（限制长度）
                data = result.get('data', '')
                if len(data) > 200:
                    print(f"   数据预览: {data[:200]}...")
                else:
                    print(f"   生成数据: {data}")
                    
            else:
                print(f"❌ 生成失败: {result.get('message', '未知错误')}")
                
        except Exception as e:
            print(f"❌ 请求失败: {e}")
        
        time.sleep(0.5)  # 短暂等待
    
    # 停止熵源
    print("\n🛑 停止熵源系统...")
    stop_response = requests.post(f"{base_url}/api/stop")
    if stop_response.json().get('success'):
        print("✅ 熵源停止成功")
    else:
        print("❌ 熵源停止失败")

if __name__ == "__main__":
    print("🧪 测试新的随机数据格式生成功能")
    print("请确保web_demo.py正在运行 (http://localhost:5000)")
    
    try:
        test_format_generation()
    except requests.exceptions.ConnectionError:
        print("❌ 无法连接到服务器，请确保web_demo.py正在运行")
    except KeyboardInterrupt:
        print("\n👋 测试被用户中断")
    except Exception as e:
        print(f"❌ 测试过程中出现错误: {e}")
